Usage
pgee.fit(N, m, X, Z = NULL, y = NULL, yc = NULL, yb = NULL, wctype = "Ind", family = "Gaussian", lambda = 0, eps = 1e-06, maxiter = 1000, tol.coef = 0.001, tol.score = 0.001, init = NULL, standardize = TRUE, penalty = "SCAD", weights = rep(1, N), FDR = FALSE, fdr.corr = NULL, fdr.type = "all")
Arguments
m
Cluster size. Assumed equal across all clusters. Should be set to 2
for family=="Mixed".
X
Design matrix. If family=="Mixed", then design matrix for continuous
responses. For family!="Mixed", should have N*m rows. For family=="Mixed",
should have N rows. For standardize=TRUE, the first column should be a
column vector of ones, corresponding to the intercept.
Z
Design matrix for binary responses for family=="Mixed". Should not
be provided for other family types. If not provided for family=="Mixed", is
set equal to X. For family!="Mixed", should have N*m rows. For
family=="Mixed", should have N rows. For standardize=TRUE, the first
column should be a column vector of ones, corresponding to the intercept.
y
Response vector. Don't use this argument for family == "Mixed".
Instead, use arguments yc and yb. Since the cluster size is assumed equal
across clusters, the vector is assumed to have the form c(y_1,
y_2,...,y_N), with y_i = c(y_i1,...,y_im).
yc
Continuous response vector. Use only for family=="Mixed".
yb
Binary (0/1) response vector. Use only for family=="Mixed".
wctype
Working correlation type; one of "Ind", "CS", or "AR1". For
family=="Mixed", "CS" and "AR1" are equivalent.
family
"Gaussian", "Binomial", or "Mixed" (use the last for bivariate
mixed outcomes). Note that for "Binomial", currently only binary outcomes
are supported.
lambda
Tuning parameter(s). A vector of two tuning parameters should
be provided for family=="Mixed" (one for the continuous outcome
coefficients, and one of the binary outcome coefficients). Otherwise, a
single tuning parameter should be provided.
eps
Disturbance in the Linear Quadratic Approximation algorithm.
maxiter
The maximum number of iterations the Newton algorithm tries
before declaring failure to converge.
tol.coef
Converge of the Newton algorithm is declared if two
conditions are met: The L1-norm of the difference of successive iterates
should be less than tol.coef AND the L1-norm of the penalized score should
be less than tol.score.
init
Vector of initial values for regression coefficients. For
family=="Mixed", should be c(init_c, init_b). Defaults to glm values.
standardize
Standardize the design matrices prior to estimation?
penalty
"SCAD", "MCP", or "LASSO".
weights
Vector of cluster weights. All observations in a cluster are
assumed to have the same weight.
FDR
Should the false discovery rate be estimated for family=="Mixed"?
Currently, FDR cannot be estimated for other family types.
fdr.corr
Association parameter to use in FDR estimation. The default
is to use the association parameter estimated from the PGEEs.
fdr.type
Estimate the FDR for only the coefficients corresponding to
the continuous outcomes ("continuous"), for only the coefficients
corresponding to the binary outcomes ("binary"), or for all coefficients
("all", the default).